Index: ixgbe.c
===================================================================
--- ixgbe.c	(revision 208950)
+++ ixgbe.c	(working copy)
@@ -284,6 +284,13 @@
 static int ixgbe_rxd = PERFORM_RXD;
 TUNABLE_INT("hw.ixgbe.rxd", &ixgbe_rxd);
 
+/* 
+ * Allow configuration of unsupported SFPs.  
+ * Use at your own risk. 
+ */
+int ixgbe_allow_unsupported_sfp = 0;
+TUNABLE_INT("hw.ixgbe.allow_unsupported_sfp", &ixgbe_allow_unsupported_sfp);
+
 /* Keep running tab on them for sanity check */
 static int ixgbe_total_ports;
 
Index: ixgbe_phy.c
===================================================================
--- ixgbe_phy.c	(revision 208950)
+++ ixgbe_phy.c	(working copy)
@@ -49,6 +49,8 @@
 static bool ixgbe_get_i2c_data(u32 *i2cctl);
 void ixgbe_i2c_bus_clear(struct ixgbe_hw *hw);
 
+extern int ixgbe_allow_unsupported_sfp;
+
 /**
  *  ixgbe_init_phy_ops_generic - Inits PHY function ptrs
  *  @hw: pointer to the hardware structure
@@ -1106,7 +1108,8 @@
 		}
 
 		ixgbe_get_device_caps(hw, &enforce_sfp);
-		if (!(enforce_sfp & IXGBE_DEVICE_CAPS_ALLOW_ANY_SFP)) {
+		if (!(enforce_sfp & IXGBE_DEVICE_CAPS_ALLOW_ANY_SFP) && 
+		    (ixgbe_allow_unsupported_sfp == 0)) {
 			/* Make sure we're a supported PHY type */
 			if (hw->phy.type == ixgbe_phy_sfp_intel) {
 				status = IXGBE_SUCCESS;
Index: ixgbe_osdep.h
===================================================================
--- ixgbe_osdep.h	(revision 208950)
+++ ixgbe_osdep.h	(working copy)
@@ -67,6 +67,7 @@
 	#define DEBUGOUT1(S,A)      printf(S "\n",A)
 	#define DEBUGOUT2(S,A,B)    printf(S "\n",A,B)
 	#define DEBUGOUT3(S,A,B,C)  printf(S "\n",A,B,C)
+	#define DEBUGOUT6(S,A,B,C,D,E,F)    printf(S "\n",A,B,C,D,E,F)
 	#define DEBUGOUT7(S,A,B,C,D,E,F,G)  printf(S "\n",A,B,C,D,E,F,G)
 #else
 	#define DEBUGOUT(S)